@@ -9,7 +9,7 @@ sentry_wechat.models
 """
 
 import json
-import requests
+import grequests
 from datetime import datetime
 from pytz import timezone
 
@@ -64,8 +64,6 @@ class WechatPlugin(NotificationPlugin):
         if self.should_notify(group, event):
             self.logger.info('send msg to wechat robot yes')
             self.post_base_process(group, event, *args, **kwargs)
-            self.post_main_process(group, event, *args, **kwargs)
-
         else:
             self.logger.info('send msg to wechat robot no')
             return None
@@ -84,51 +82,37 @@ class WechatPlugin(NotificationPlugin):
                 "news": {
                 "articles" : [
                         {
-                            "title" : title,
-                            "url" : url,
-                            "description" : description,
+                            "title" : title or "",
+                            "url" : url or "",
+                            "description" : description or "",
                             "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
                         }
                     ]
                 }
         }
 
-        requests.post(
-            url=send_url,
-            headers={"Content-Type": "application/json"},
-            data=json.dumps(data)
-        )
-
-    def post_main_process(self, group, event, *args, **kwargs):
-        """
-        Process error.
-        """
-        send_url = self.get_webhook_urls(group.project)
-        description = event.title or event.message
-        url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
-
         main_data = {
                 "msgtype": "markdown",
                 "markdown": {
                     "content": u"#### {title} \n > 环境: <font color=\"info\">{environment}</font> \n > 等级: <font color=\"warning\">{level}</font> \n > 版本: <font color=\"comment\">{release}</font> \n > 浏览器: <font color=\"comment\">{browser}</font> \n > 操作系统: <font color=\"comment\">{os}</font> \n > 域名: <font color=\"comment\">{domain}</font> \n > 用户: <font color=\"comment\">{user}</font> \n > 报错信息: <font color=\"comment\">{message}</font> \n > 触发点: <font color=\"comment\">{culprit}</font> \n > 创建日期: <font color=\"comment\">{dateCreated}</font> \n > [怼我看BUG!]({url})".format(
                         title="详情",
-                        environment=event.get_tag("environment"),
-                        level=event.get_tag("level"),
-                        release=event.get_tag("release"),
-                        browser=event.get_tag("browser"),
-                        os=event.get_tag("os"),
-                        domain=event.get_tag("url"),
-                        user=event.get_tag("user"),
-                        message=description,
-                        culprit=event.culprit,
-                        dateCreated=datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"),
-                        url=url,
+                        environment=event.get_tag("environment") or "",
+                        level=event.get_tag("level") or "",
+                        release=event.get_tag("release") or "",
+                        browser=event.get_tag("browser") or "",
+                        os=event.get_tag("os") or "",
+                        domain=event.get_tag("url") or "",
+                        user=event.get_tag("user") or "",
+                        message=description or "",
+                        culprit=event.culprit or "",
+                        dateCreated=datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S") or "",
+                        url=url or "",
                     )
                 }
         }
 
-        requests.post(
-            url=send_url,
-            headers={"Content-Type": "application/json"},
-            data=json.dumps(main_data)
-        )
\ No newline at end of file
+        req_list = [   # 请求列表
+            grequests.post(send_url,headers={"Content-Type": "application/json"},data=json.dumps(data)),
+            grequests.post(send_url,headers={"Content-Type": "application/json"},data=json.dumps(main_data)),
+        ]
+        grequests.map(req_list)
\ No newline at end of file
